pub enum Call<T: Config> {
transfer {
currency_id: T::CurrencyId,
amount: T::Balance,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
},
transfer_multiasset {
asset: Box<VersionedAsset>,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
},
transfer_with_fee {
currency_id: T::CurrencyId,
amount: T::Balance,
fee: T::Balance,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
},
transfer_multiasset_with_fee {
asset: Box<VersionedAsset>,
fee: Box<VersionedAsset>,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
},
transfer_multicurrencies {
currencies: Vec<(T::CurrencyId, T::Balance)>,
fee_item: u32,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
},
transfer_multiassets {
assets: Box<VersionedAssets>,
fee_item: u32,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
transfer
Transfer native currencies.
dest_weight_limit is the weight for XCM execution on the dest
chain, and it would be charged from the transferred assets. If set
below requirements, the execution may fail and assets wouldn’t be
received.
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
transfer_multiasset
Transfer Asset.
dest_weight_limit is the weight for XCM execution on the dest
chain, and it would be charged from the transferred assets. If set
below requirements, the execution may fail and assets wouldn’t be
received.
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
transfer_with_fee
Transfer native currencies specifying the fee and amount as separate.
dest_weight_limit is the weight for XCM execution on the dest
chain, and it would be charged from the transferred assets. If set
below requirements, the execution may fail and assets wouldn’t be
received.
fee is the amount to be spent to pay for execution in destination
chain. Both fee and amount will be subtracted form the callers
balance.
If fee is not high enough to cover for the execution costs in the
destination chain, then the assets will be trapped in the
destination chain
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
transfer_multiasset_with_fee
Transfer Asset specifying the fee and amount as separate.
dest_weight_limit is the weight for XCM execution on the dest
chain, and it would be charged from the transferred assets. If set
below requirements, the execution may fail and assets wouldn’t be
received.
fee is the Asset to be spent to pay for execution in
destination chain. Both fee and amount will be subtracted form the
callers balance For now we only accept fee and asset having the same
Location id.
If fee is not high enough to cover for the execution costs in the
destination chain, then the assets will be trapped in the
destination chain
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
Fields
asset: Box<VersionedAsset>fee: Box<VersionedAsset>dest: Box<VersionedLocation>dest_weight_limit: WeightLimittransfer_multicurrencies
Transfer several currencies specifying the item to be used as fee
dest_weight_limit is the weight for XCM execution on the dest
chain, and it would be charged from the transferred assets. If set
below requirements, the execution may fail and assets wouldn’t be
received.
fee_item is index of the currencies tuple that we want to use for
payment
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
Fields
currencies: Vec<(T::CurrencyId, T::Balance)>dest: Box<VersionedLocation>dest_weight_limit: WeightLimittransfer_multiassets
Transfer several Asset specifying the item to be used as fee
dest_weight_limit is the weight for XCM execution on the dest
chain, and it would be charged from the transferred assets. If set
below requirements, the execution may fail and assets wouldn’t be
received.
fee_item is index of the Assets that we want to use for
payment
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
Implementations
Sourceimpl<T: Config> Call<T>
impl<T: Config> Call<T>
Sourcepub fn new_call_variant_transfer(
currency_id: T::CurrencyId,
amount: T::Balance,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
) -> Self
pub fn new_call_variant_transfer( currency_id: T::CurrencyId, amount: T::Balance, dest: Box<VersionedLocation>, dest_weight_limit: WeightLimit, ) -> Self
Create a call with the variant transfer.
Sourcepub fn new_call_variant_transfer_multiasset(
asset: Box<VersionedAsset>,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
) -> Self
pub fn new_call_variant_transfer_multiasset( asset: Box<VersionedAsset>, dest: Box<VersionedLocation>, dest_weight_limit: WeightLimit, ) -> Self
Create a call with the variant transfer_multiasset.
Sourcepub fn new_call_variant_transfer_with_fee(
currency_id: T::CurrencyId,
amount: T::Balance,
fee: T::Balance,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
) -> Self
pub fn new_call_variant_transfer_with_fee( currency_id: T::CurrencyId, amount: T::Balance, fee: T::Balance, dest: Box<VersionedLocation>, dest_weight_limit: WeightLimit, ) -> Self
Create a call with the variant transfer_with_fee.
Sourcepub fn new_call_variant_transfer_multiasset_with_fee(
asset: Box<VersionedAsset>,
fee: Box<VersionedAsset>,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
) -> Self
pub fn new_call_variant_transfer_multiasset_with_fee( asset: Box<VersionedAsset>, fee: Box<VersionedAsset>, dest: Box<VersionedLocation>, dest_weight_limit: WeightLimit, ) -> Self
Create a call with the variant transfer_multiasset_with_fee.
Sourcepub fn new_call_variant_transfer_multicurrencies(
currencies: Vec<(T::CurrencyId, T::Balance)>,
fee_item: u32,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
) -> Self
pub fn new_call_variant_transfer_multicurrencies( currencies: Vec<(T::CurrencyId, T::Balance)>, fee_item: u32, dest: Box<VersionedLocation>, dest_weight_limit: WeightLimit, ) -> Self
Create a call with the variant transfer_multicurrencies.
Sourcepub fn new_call_variant_transfer_multiassets(
assets: Box<VersionedAssets>,
fee_item: u32,
dest: Box<VersionedLocation>,
dest_weight_limit: WeightLimit,
) -> Self
pub fn new_call_variant_transfer_multiassets( assets: Box<VersionedAssets>, fee_item: u32, dest: Box<VersionedLocation>, dest_weight_limit: WeightLimit, ) -> Self
Create a call with the variant transfer_multiassets.