pub enum Error<T> {
Show 20 variants
AssetHasNoReserve,
NotCrossChainTransfer,
InvalidDest,
NotCrossChainTransferableCurrency,
UnweighableMessage,
XcmExecutionFailed,
CannotReanchor,
InvalidAncestry,
InvalidAsset,
DestinationNotInvertible,
BadVersion,
DistinctReserveForAssetAndFee,
ZeroFee,
ZeroAmount,
TooManyAssetsBeingSent,
AssetIndexNonExistent,
FeeNotEnough,
NotSupportedLocation,
MinXcmFeeNotDefined,
RateLimited,
// some variants omitted
}Expand description
The Error enum of this pallet.
Variants
AssetHasNoReserve
Asset has no reserve location.
NotCrossChainTransfer
Not cross-chain transfer.
InvalidDest
Invalid transfer destination.
NotCrossChainTransferableCurrency
Currency is not cross-chain transferable.
UnweighableMessage
The message’s weight could not be determined.
XcmExecutionFailed
XCM execution failed.
CannotReanchor
Could not re-anchor the assets to declare the fees for the destination chain.
InvalidAncestry
Could not get ancestry of asset reserve location.
InvalidAsset
The Asset is invalid.
DestinationNotInvertible
The destination Location provided cannot be inverted.
BadVersion
The version of the Versioned value used is not able to be
interpreted.
DistinctReserveForAssetAndFee
We tried sending distinct asset and fee but they have different reserve chains.
ZeroFee
The fee is zero.
ZeroAmount
The transferring asset amount is zero.
TooManyAssetsBeingSent
The number of assets to be sent is over the maximum.
AssetIndexNonExistent
The specified index does not exist in a Assets struct.
FeeNotEnough
Fee is not enough.
NotSupportedLocation
Not supported Location
MinXcmFeeNotDefined
MinXcmFee not registered for certain reserve location
RateLimited
Asset transfer is limited by RateLimiter.