Struct orml_xtokens::module::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
pub fn transfer(
origin: OriginFor<T>,
currency_id: T::CurrencyId,
amount: T::Balance,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
pub fn transfer(
origin: OriginFor<T>,
currency_id: T::CurrencyId,
amount: T::Balance,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
Transfer native currencies.
dest_weight is the weight for XCM execution on the dest chain, and
it would be charged from the transferred assets. If set below
requirements, the execution may fail and assets wouldn’t be
received.
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
pub fn transfer_multiasset(
origin: OriginFor<T>,
asset: Box<VersionedMultiAsset>,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
pub fn transfer_multiasset(
origin: OriginFor<T>,
asset: Box<VersionedMultiAsset>,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
Transfer MultiAsset.
dest_weight is the weight for XCM execution on the dest chain, and
it would be charged from the transferred assets. If set below
requirements, the execution may fail and assets wouldn’t be
received.
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
pub fn transfer_with_fee(
origin: OriginFor<T>,
currency_id: T::CurrencyId,
amount: T::Balance,
fee: T::Balance,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
pub fn transfer_with_fee(
origin: OriginFor<T>,
currency_id: T::CurrencyId,
amount: T::Balance,
fee: T::Balance,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
Transfer native currencies specifying the fee and amount as separate.
dest_weight is the weight for XCM execution on the dest chain, and
it would be charged from the transferred assets. If set below
requirements, the execution may fail and assets wouldn’t be
received.
fee is the amount to be spent to pay for execution in destination
chain. Both fee and amount will be subtracted form the callers
balance.
If fee is not high enough to cover for the execution costs in the
destination chain, then the assets will be trapped in the
destination chain
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.
pub fn transfer_multiasset_with_fee(
origin: OriginFor<T>,
asset: Box<VersionedMultiAsset>,
fee: Box<VersionedMultiAsset>,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
pub fn transfer_multiasset_with_fee(
origin: OriginFor<T>,
asset: Box<VersionedMultiAsset>,
fee: Box<VersionedMultiAsset>,
dest: Box<VersionedMultiLocation>,
dest_weight: Weight
) -> DispatchResult
Transfer MultiAsset specifying the fee and amount as separate.
dest_weight is the weight for XCM execution on the dest chain, and
it would be charged from the transferred assets. If set below
requirements, the execution may fail and assets wouldn’t be
received.
fee is the multiasset to be spent to pay for execution in
destination chain. Both fee and amount will be subtracted form the
callers balance For now we only accept fee and asset having the same
MultiLocation id.
If fee is not high enough to cover for the execution costs in the
destination chain, then the assets will be trapped in the
destination chain
It’s a no-op if any error on local XCM execution or message sending. Note sending assets out per se doesn’t guarantee they would be received. Receiving depends on if the XCM message could be delivered by the network, and if the receiving chain would handle messages correctly.